@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.001000';
 
 1;
 
@@ -20,7 +20,7 @@ WebService::MinFraud - API for MaxMind's minFraud Score, Insights, and Factors s
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -58,7 +58,7 @@ version 1.000001
 =head1 DESCRIPTION
 
 This distribution provides an API for the
-L<MaxMind minFraud Score, Insights, and Factors web services|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
+L<MaxMind minFraud Score, Insights, and Factors web services|https://dev.maxmind.com/minfraud/>.
 
 See L<WebService::MinFraud::Client> for details on using the web service client
 API.
@@ -98,7 +98,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Dave Rolsky Greg Oschwald
+=for stopwords Andy Jack Dave Rolsky Greg Oschwald Patrick Cronin
 
 =over 4
 
@@ -114,6 +114,10 @@ Dave Rolsky <drolsky@maxmind.com>
 
 Greg Oschwald <goschwald@maxmind.com>
 
+=item *
+
+Patrick Cronin <PatrickCronin@users.noreply.github.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
