@@ -3,7 +3,7 @@ package WebService::MinFraud::Client;
 use 5.010;
 use Moo 1.004005;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.001000';
 
 use HTTP::Headers ();
 use HTTP::Request ();
@@ -307,7 +307,7 @@ WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insight
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -347,7 +347,7 @@ version 1.000001
 This class provides a client API for the MaxMind minFraud Score, Insights, and
 Factors web services. The B<Insights> service returns more data about a
 transaction than the B<Score> service. See the
-L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
+L<API documentation|https://dev.maxmind.com/minfraud/>
 for more details.
 
 Each web service is represented by a different model class, and
@@ -486,7 +486,7 @@ dotted-quad notation or the IPv6 hexadecimal-colon notation.
 =head1 REQUEST METHODS
 
 All of the request methods require a device ip_address. See the
-L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
+L<API documentation|https://dev.maxmind.com/minfraud/>
 for details on all the values that can be part of the request. Portions of the
 request hash with undefined and empty string values are automatically removed
 from the request.
@@ -519,7 +519,7 @@ support policies for dependencies and Perl itself.
 
 For details on the possible errors returned by the web service itself, please
 refer to the
-L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
+L<API documentation|https://dev.maxmind.com/minfraud/>.
 
 Prior to making the request to the web service, the request HashRef is passed
 to L<WebService::MinFraud::Validator> for checks. If the request fails
@@ -548,7 +548,7 @@ sort of (hopefully) useful error message.
 =head1 WHAT DATA IS RETURNED?
 
 Please see the
-L<API documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
+L<API documentation|https://dev.maxmind.com/minfraud/>
 for details on what data each web service may return.
 
 Every record class attribute has a corresponding predicate method so that you
