@@ -2,7 +2,7 @@ package WebService::MinFraud::Model::Insights;
 
 use Moo;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.001000';
 
 use Types::Standard qw( HashRef InstanceOf );
 use WebService::MinFraud::Record::BillingAddress;
@@ -43,7 +43,7 @@ WebService::MinFraud::Model::Insights - Model class for minFraud Insights
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ service.
 
 The Insights model class includes more data than the Score model class. See
 the L<API
-documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>
+documentation|https://dev.maxmind.com/minfraud/>
 for more details.
 
 =head1 METHODS
