@@ -2,7 +2,7 @@ package WebService::MinFraud::Model::Score;
 
 use Moo;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.001000';
 
 use WebService::MinFraud::Record::ScoreIPAddress;
 
@@ -28,7 +28,7 @@ WebService::MinFraud::Model::Score - Model class for minFraud: Score
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ This class provides a model for the data returned by the minFraud Score
 web service.
 
 For more details, see the L<API
-documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/>.
+documentation|https://dev.maxmind.com/minfraud/>.
 
 =head1 METHODS
 
