@@ -2,7 +2,7 @@ package WebService::MinFraud::Record::Warning;
 
 use Moo;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.001000';
 
 use Types::Standard qw( ArrayRef Str );
 
@@ -37,7 +37,7 @@ WebService::MinFraud::Record::Warning - A warning record returned from a web ser
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ This class provides the following methods:
 =head2 code
 
 Returns a machine-readable code identifying the warning. See the L<API
-documentation|https://dev.maxmind.com/minfraud/minfraud-score-and-insights-api-documentation/#Warning_Object>
+documentation|https://dev.maxmind.com/minfraud/#Warning>
 for the current list.
 
 =head2 input_pointer
